#!/usr/bin/env python

"""
Logger example layout
v1

Please adjust config.ini file. EasyTerm can be connected through USB or through USB-UART adapter
See manual (chapter "Master connection configurations") in case of problems
"""

import serial
import easyterm_api
import configparser
config = configparser.ConfigParser(inline_comment_prefixes="#")
config.read('config.ini')

with serial.Serial(config['COM']['CFG_COM_PORT'], int(config['COM']['CFG_BAUD_RATE']), timeout=float(config['COM']['CFG_REPLY_TIMEOUT'])) as ser:    
    et = easyterm_api.EasyTermApi(ser)
    
    #Uncomment to reset
    #et.soft_reset()
    
    #Clear current screen page to make sure there is space for widgets
    et.clear_screen_page()
    
    #Header
    et.transceive('dg x=60 y=5 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    et.transceive('dt a=c x=160 y=10 t="Logger" f=18b;', echo=True)
    et.transceive('dg x=60 y=30 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    
    #LogWindow
    et.transceive('dl y=35 h=160;', echo=True)
    
    #Log filter
    et.transceive('dt x=160 y=199 bw=300 t="Log filter(exclusions)" a=c ld=l;', echo=True)
    et.transceive('dc x=3 y=215 c=0,0,100 w=78 h=30 t="Commands" ta="FilterLog ec=1" ua="FilterLog ec=0" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=0;', echo=True)
    et.transceive('dc x=82 y=215 c=0,0,100 w=78 h=30 t="Text" ta="FilterLog et=1" ua="FilterLog et=0" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=1;', echo=True)
    et.transceive('dc x=161 y=215 c=0,0,100 w=78 h=30 t="Parsed" ta="FilterLog ep=1" ua="FilterLog ep=0" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=2;', echo=True)
    et.transceive('dc x=240 y=215 c=0,0,100 w=78 h=30 t="Replies" ta="FilterLog er=1" ua="FilterLog er=0" is=100 ot=1 bc=40,40,40 utc=60,60,60 to=c id=3;', echo=True)
    
    #Log operations
    et.transceive('dt x=160 y=245 bw=300 t="Log operations" a=c ld=l;', echo=True)
    et.transceive('db x=3 y=261 c=0,0,100 w=104 h=30 t="Stop log" a="STOPLOG";', echo=True)
    et.transceive('db x=108 y=261 c=0,0,100 w=104 h=30 t="Resume log" a="RESUMELOG";', echo=True)
    et.transceive('db x=213 y=261 c=0,0,100 w=104 h=30 t="Clear log" a="CLEARLOG";', echo=True)
    
    #Runtime log
    et.transceive('dt x=160 y=291 bw=300 t="Runtime log" a=c ld=l;', echo=True)
    et.transceive('db x=3 y=307 c=0,0,100 w=157 h=30 t="Save to FLASH" a="SaveLog bid=%d";', echo=True)
    et.transceive('db x=161 y=307 c=0,0,100 w=157 h=30 t="Load from FLASH" a="LoadLog bid=%d";', echo=True)
    
    #Log recorder (to FLASH)
    et.transceive('dt x=160 y=339 bw=300 t="Log recorder (to FLASH)" a=c ld=l;', echo=True)
    et.transceive('db x=3 y=355 c=0,0,100 w=104 h=30 t="Start recording" a="RecordLog bid=%d";', echo=True)
    et.transceive('db x=108 y=355 c=0,0,100 w=104 h=30 t="Stop recording" a="RecordLogStop";', echo=True)
    et.transceive('db x=213 y=355 c=0,0,100 w=104 h=30 t="List logs" a="ListLogs";', echo=True)
    
    
    #Print runtime log to host
    et.transceive('dt x=160 y=386 bw=300 t="Print runtime log to host" a=c ld=l;', echo=True)
    et.transceive('db x=3 y=402 c=0,0,100 w=104 h=30 t="Print" a="PrintLog pd=1";', echo=True)
    et.transceive('db x=108 y=402 c=0,0,100 w=104 h=30 t="Print (no date)" a="PrintLog pd=0";', echo=True)
    et.transceive('db x=213 y=402 c=0,0,100 w=104 h=30 t="Print (no date,time)" a="PrintLog pd=0 pt=0";', echo=True)
    
    
    #Print stored log to host
    et.transceive('dt x=160 y=434 bw=300 t="Print stored log to host" a=c ld=l;', echo=True)
    et.transceive('db x=3 y=450 c=0,0,100 w=104 h=30 t="Print" a="PrintLog pd=1 bid=%d";', echo=True)
    et.transceive('db x=108 y=450 c=0,0,100 w=104 h=30 t="Print (no date)" a="PrintLog bid=%d pd=0";', echo=True)
    et.transceive('db x=213 y=450 c=0,0,100 w=104 h=30 t="Print (no date,time)" a="PrintLog bid=%d pd=0 pt=0";', echo=True)
    
    
    #Uncomment to save layout in flash and recover after device startup
    #et.transceive('sl bid=0;', echo=True, custom_timeout=2)
    #et.transceive('sys coi="ll bid=0";', echo=True, custom_timeout=2)
    
